@@ -50,7 +50,7 @@ typedef enum {
 
 /* The GthTransform numeric values range from 1 to 8, corresponding to
  * the valid range of Exif orientation tags.  The name associated with each
- * numeric valid describes the data transformation required that will allow
+ * numeric value describes the data transformation required that will allow
  * the orientation value to be reset to "1" without changing the displayed
  * image.
  * GthTransform and ExifShort values are interchangeably in a number of
@@ -94,6 +94,7 @@ typedef enum {
 	GTH_ASPECT_RATIO_16x10,
 	GTH_ASPECT_RATIO_16x9,
 	GTH_ASPECT_RATIO_185x100,
+	GTH_ASPECT_RATIO_191x100,
 	GTH_ASPECT_RATIO_239x100,
 	GTH_ASPECT_RATIO_CUSTOM
 } GthAspectRatio;
@@ -137,7 +138,8 @@ typedef enum /*< skip >*/ {
 typedef enum /*< skip >*/ {
 	GTH_COLOR_SPACE_UNKNOWN,
 	GTH_COLOR_SPACE_SRGB,
-	GTH_COLOR_SPACE_UNCALIBRATED
+	GTH_COLOR_SPACE_ADOBERGB,
+	GTH_COLOR_SPACE_UNCALIBRATED,
 } GthColorSpace;
 
 
@@ -162,16 +164,19 @@ typedef enum /*< skip >*/ {
 	/* Shortcut available when the window is in viewer mode. */
 	GTH_SHORTCUT_CONTEXT_VIEWER = 1 << 4,
 
+	/* Shortcut available when the window is in editor mode. */
+	GTH_SHORTCUT_CONTEXT_EDITOR = 1 << 5,
+
 	/* Shortcut available in slideshows. */
-	GTH_SHORTCUT_CONTEXT_SLIDESHOW = 1 << 5,
+	GTH_SHORTCUT_CONTEXT_SLIDESHOW = 1 << 6,
 
 	/* Entry used for documentation only. */
-	GTH_SHORTCUT_CONTEXT_DOC = 1 << 6,
+	GTH_SHORTCUT_CONTEXT_DOC = 1 << 7,
 
 	/* Aggregated values: */
 
 	GTH_SHORTCUT_CONTEXT_BROWSER_VIEWER = (GTH_SHORTCUT_CONTEXT_BROWSER | GTH_SHORTCUT_CONTEXT_VIEWER),
-	GTH_SHORTCUT_CONTEXT_ANY = (GTH_SHORTCUT_CONTEXT_BROWSER | GTH_SHORTCUT_CONTEXT_VIEWER | GTH_SHORTCUT_CONTEXT_SLIDESHOW),
+	GTH_SHORTCUT_CONTEXT_ANY = (GTH_SHORTCUT_CONTEXT_BROWSER | GTH_SHORTCUT_CONTEXT_VIEWER | GTH_SHORTCUT_CONTEXT_EDITOR | GTH_SHORTCUT_CONTEXT_SLIDESHOW),
 } GthShortcutContext;
 
 
